django_analyses.models.output package — django_analyses 0.0.3 documentation

# django_analyses.models.output package

## Subpackages

- django_analyses.models.output.definitions package
  - Submodules
  - django_analyses.models.output.definitions.file_output_definition module
  - django_analyses.models.output.definitions.float_output_definition module
  - django_analyses.models.output.definitions.output_definition module
  - django_analyses.models.output.definitions.output_definitions module
  - Module contents
- django_analyses.models.output.types package
  - Submodules
  - django_analyses.models.output.types.file_output module
  - django_analyses.models.output.types.float_output module
  - django_analyses.models.output.types.output_types module
  - Module contents

## Submodules

## django_analyses.models.output.output module

class `django_analyses.models.output.output.` `Output`(id, run)

  Bases: `django.db.models.base.Model`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `definition` = None
  `fileoutput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `floatoutput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `key`
  `objects` = <model_utils.managers.InheritanceManager object>
  `pre_save`() → None
  `run`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `run_id`
  `save`(*args, **kwargs)

    Save the current instance. Override this in a subclass if you want to control the saving process.

    The ‘force_insert’ and ‘force_update’ parameters can be used to insist that the “save” must be an SQL insert or update (or equivalent for non-SQL backends), respectively. Normally, they should not be set.

  `validate`() → None
  `value` = None

## django_analyses.models.output.output_specification module

class `django_analyses.models.output.output_specification.` `OutputSpecification`(id, created, modified, analysis)

  Bases: `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `analysis_id`
  `analysis_version_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `base_output_definitions`

    Accessor to the related objects manager on the forward and reverse sides of a many-to-many relation.

    In the example:

        class Pizza(Model):
            toppings = ManyToManyField(Topping, related_name='pizzas')

    `Pizza.toppings` and `Topping.pizzas` are `ManyToManyDescriptor` instances.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `objects` = <django_analyses.models.managers.output_specification.OutputSpecificationManager object>
  property `output_definitions`

## Module contents